@@ -30,7 +30,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * @(#) $Header: /nfs/jade/vint/CVSROOT/nam-1/main.cc,v 1.55 2002/12/17 01:06:28 buchheim Exp $ (LBL)
+ * @(#) $Header: /cvsroot/nsnam/nam-1/main.cc,v 1.57 2003/10/11 22:56:50 xuanc Exp $ (LBL)
  */
 
 #include <stdlib.h>
@@ -211,7 +211,7 @@ void adios()
 	exit(0);
 }
 
-static int cmd_adios(ClientData , Tcl_Interp* , int , char **)
+static int cmd_adios(ClientData , Tcl_Interp* , int , CONST84 char **)
 {
 	adios();
 	/*NOTREACHED*/
@@ -220,7 +220,7 @@ static int cmd_adios(ClientData , Tcl_Interp* , int , char **)
 
 extern "C" char version[];
 
-static int cmd_version(ClientData , Tcl_Interp* tcl, int , char **)
+static int cmd_version(ClientData , Tcl_Interp* tcl, int , CONST84 char **)
 {
 	tcl->result = version;
 	return (TCL_OK);
@@ -336,13 +336,21 @@ main(int argc, char **argv) {
 		abort();
 	}
 #endif
+
 #if TCL_MAJOR_VERSION < 8
-	Tcl_SetVar(interp, "tcl_library", "./lib/tcl7.6", TCL_GLOBAL_ONLY);
-	Tcl_SetVar(interp, "tk_library", "./lib/tk4.2", TCL_GLOBAL_ONLY);
+        Tcl_SetVar(interp, "tcl_library", "./lib/tcl7.6", TCL_GLOBAL_ONLY);
+        Tcl_SetVar(interp, "tk_library", "./lib/tk4.2", TCL_GLOBAL_ONLY);
 #else
-	Tcl_SetVar(interp, "tcl_library", "./lib/tcl8.0", TCL_GLOBAL_ONLY);
-	Tcl_SetVar(interp, "tk_library", "./lib/tk8.0", TCL_GLOBAL_ONLY);
+        Tcl_SetVar(interp, "tcl_library", "", TCL_GLOBAL_ONLY);
+        Tcl_SetVar(interp, "tk_library", "", TCL_GLOBAL_ONLY);
+                                                                                
+        // this seems just a hack, should NOT have hard-coded library path!
+        // why there's no problem with old  TCL/TK?
+        // xuanc, 10/3/2003
+        //Tcl_SetVar(interp, "tcl_library", "./lib/tcl8.0", TCL_GLOBAL_ONLY);
+        //Tcl_SetVar(interp, "tk_library", "./lib/tk8.0", TCL_GLOBAL_ONLY);
 #endif
+
 	if (Otcl_Init(interp) == TCL_ERROR) {
 		printf("%s\n", interp->result);
 		abort();
@@ -367,7 +375,6 @@ main(int argc, char **argv) {
 		tk = Tk_MainWindow(tcl.interp());
 	if (tk == 0) {
 		fprintf(stderr, "nam: %s\n", interp->result);
-		Tcl_DeleteInterp(interp);
 		exit(1);
 	}
 	tcl.tkmain(tk);
